Chat.render_inner_html() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# Chat.render_inner_html()

Chat.render_inner_html(template_data: dict) → str

  Renders the element template `element_template`.

  Parameters

    template_data – A dictionary of data for rendering the template.

  Notes

  If no element_template is defined, None is returned. Usually, the inner html gets placed into the higher-level :attr: .base_template, when `Element.web_widget` gets called.

  Returns

    Inner html code for this element.

  Return type

    str